@@ -6,7 +6,7 @@ use PDF::Class::Type;
 # /Type /Group - a node in the page tree
 class PDF::Group
     is PDF::COS::Dict
-    does PDF::Class::Type {
+    does PDF::Class::Type['Type','S'] {
 
     # see [PDF 1.7 TABLE 10.12 Entries in an object reference dictionary]
     use PDF::COS::Tie;
